from pdf4me.model import UsageSubscriptionReq, UsageApplicationReq


class ManagementClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def check_availability(self):  
        """check_availability  

        :return: CheckAvailabilityRes
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params,
                                                         controller='Management/CheckAvailability')

    def get_api_call_detail(self, api_call_id):  
        """get_api_call_detail  

        :param str api_call_id:
        :return: ApiCallDetail
        """
        params = [('apiCallId', api_call_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Management/GetApiCallDetail')

    def get_latest_package(self):  
        """get_latest_package  

        :return: Package
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Management/GetLatestPackage')

    def get_subscription_usage(self):  
        """get_subscription_usage  

        :return: SubscriptionUsage
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object={},
                                                                    controller='Management/GetSubscriptionUsage')

    def get_usage_application(self, usage_application_req):  
        """get_usage_application  

        :param UsageApplicationReq usage_application_req:
        :return: UsageApplicationRes
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object=usage_application_req,
                                                                    controller='Management/GetUsageApplication')

    def get_usage_subscription(self, usage_subscription_req):  
        """get_usage_subscription  

        :param UsageSubscriptionReq usage_subscription_req:
        :return: UsageSubscriptionRes
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object=usage_subscription_req,
                                                                    controller='Management/GetUsageSubscription')

    def version(self):  
        """Version  

        A simple method to get the current Version  
        :return: VersionRes
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object={}, controller='Management/Version')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MailingConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_print': 'bool',
        'archive': 'bool',
        'print_pool_name': 'str',
        'production_session': 'str'
    }

    attribute_map = {
        '_print': 'print',
        'archive': 'archive',
        'print_pool_name': 'printPoolName',
        'production_session': 'productionSession'
    }

    def __init__(self, _print=None, archive=None, print_pool_name=None, production_session=None):  # noqa: E501
        """MailingConfig - a model defined in Swagger"""  # noqa: E501

        self.__print = None
        self._archive = None
        self._print_pool_name = None
        self._production_session = None
        self.discriminator = None

        if _print is not None:
            self._print = _print
        if archive is not None:
            self.archive = archive
        if print_pool_name is not None:
            self.print_pool_name = print_pool_name
        if production_session is not None:
            self.production_session = production_session

    @property
    def _print(self):
        """Gets the _print of this MailingConfig.  # noqa: E501


        :return: The _print of this MailingConfig.  # noqa: E501
        :rtype: bool
        """
        return self.__print

    @_print.setter
    def _print(self, _print):
        """Sets the _print of this MailingConfig.


        :param _print: The _print of this MailingConfig.  # noqa: E501
        :type: bool
        """

        self.__print = _print

    @property
    def archive(self):
        """Gets the archive of this MailingConfig.  # noqa: E501


        :return: The archive of this MailingConfig.  # noqa: E501
        :rtype: bool
        """
        return self._archive

    @archive.setter
    def archive(self, archive):
        """Sets the archive of this MailingConfig.


        :param archive: The archive of this MailingConfig.  # noqa: E501
        :type: bool
        """

        self._archive = archive

    @property
    def print_pool_name(self):
        """Gets the print_pool_name of this MailingConfig.  # noqa: E501


        :return: The print_pool_name of this MailingConfig.  # noqa: E501
        :rtype: str
        """
        return self._print_pool_name

    @print_pool_name.setter
    def print_pool_name(self, print_pool_name):
        """Sets the print_pool_name of this MailingConfig.


        :param print_pool_name: The print_pool_name of this MailingConfig.  # noqa: E501
        :type: str
        """

        self._print_pool_name = print_pool_name

    @property
    def production_session(self):
        """Gets the production_session of this MailingConfig.  # noqa: E501


        :return: The production_session of this MailingConfig.  # noqa: E501
        :rtype: str
        """
        return self._production_session

    @production_session.setter
    def production_session(self, production_session):
        """Sets the production_session of this MailingConfig.


        :param production_session: The production_session of this MailingConfig.  # noqa: E501
        :type: str
        """

        self._production_session = production_session

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MailingConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MailingConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SubscriptionUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subscription_id': 'str',
        'api_key': 'str',
        'total_api_cost': 'int',
        'current_api_cost': 'int',
        'sub_cost_total': 'int',
        'sub_cost_current': 'int',
        'api_call_counter': 'int',
        'active': 'bool'
    }

    attribute_map = {
        'subscription_id': 'subscriptionId',
        'api_key': 'apiKey',
        'total_api_cost': 'totalApiCost',
        'current_api_cost': 'currentApiCost',
        'sub_cost_total': 'subCostTotal',
        'sub_cost_current': 'subCostCurrent',
        'api_call_counter': 'apiCallCounter',
        'active': 'active'
    }

    def __init__(self, subscription_id=None, api_key=None, total_api_cost=None, current_api_cost=None, sub_cost_total=None, sub_cost_current=None, api_call_counter=None, active=None):  # noqa: E501
        """SubscriptionUsage - a model defined in Swagger"""  # noqa: E501

        self._subscription_id = None
        self._api_key = None
        self._total_api_cost = None
        self._current_api_cost = None
        self._sub_cost_total = None
        self._sub_cost_current = None
        self._api_call_counter = None
        self._active = None
        self.discriminator = None

        if subscription_id is not None:
            self.subscription_id = subscription_id
        if api_key is not None:
            self.api_key = api_key
        if total_api_cost is not None:
            self.total_api_cost = total_api_cost
        if current_api_cost is not None:
            self.current_api_cost = current_api_cost
        if sub_cost_total is not None:
            self.sub_cost_total = sub_cost_total
        if sub_cost_current is not None:
            self.sub_cost_current = sub_cost_current
        if api_call_counter is not None:
            self.api_call_counter = api_call_counter
        if active is not None:
            self.active = active

    @property
    def subscription_id(self):
        """Gets the subscription_id of this SubscriptionUsage.  # noqa: E501


        :return: The subscription_id of this SubscriptionUsage.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this SubscriptionUsage.


        :param subscription_id: The subscription_id of this SubscriptionUsage.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def api_key(self):
        """Gets the api_key of this SubscriptionUsage.  # noqa: E501


        :return: The api_key of this SubscriptionUsage.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this SubscriptionUsage.


        :param api_key: The api_key of this SubscriptionUsage.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def total_api_cost(self):
        """Gets the total_api_cost of this SubscriptionUsage.  # noqa: E501


        :return: The total_api_cost of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._total_api_cost

    @total_api_cost.setter
    def total_api_cost(self, total_api_cost):
        """Sets the total_api_cost of this SubscriptionUsage.


        :param total_api_cost: The total_api_cost of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._total_api_cost = total_api_cost

    @property
    def current_api_cost(self):
        """Gets the current_api_cost of this SubscriptionUsage.  # noqa: E501


        :return: The current_api_cost of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._current_api_cost

    @current_api_cost.setter
    def current_api_cost(self, current_api_cost):
        """Sets the current_api_cost of this SubscriptionUsage.


        :param current_api_cost: The current_api_cost of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._current_api_cost = current_api_cost

    @property
    def sub_cost_total(self):
        """Gets the sub_cost_total of this SubscriptionUsage.  # noqa: E501


        :return: The sub_cost_total of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._sub_cost_total

    @sub_cost_total.setter
    def sub_cost_total(self, sub_cost_total):
        """Sets the sub_cost_total of this SubscriptionUsage.


        :param sub_cost_total: The sub_cost_total of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._sub_cost_total = sub_cost_total

    @property
    def sub_cost_current(self):
        """Gets the sub_cost_current of this SubscriptionUsage.  # noqa: E501


        :return: The sub_cost_current of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._sub_cost_current

    @sub_cost_current.setter
    def sub_cost_current(self, sub_cost_current):
        """Sets the sub_cost_current of this SubscriptionUsage.


        :param sub_cost_current: The sub_cost_current of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._sub_cost_current = sub_cost_current

    @property
    def api_call_counter(self):
        """Gets the api_call_counter of this SubscriptionUsage.  # noqa: E501


        :return: The api_call_counter of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._api_call_counter

    @api_call_counter.setter
    def api_call_counter(self, api_call_counter):
        """Sets the api_call_counter of this SubscriptionUsage.


        :param api_call_counter: The api_call_counter of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._api_call_counter = api_call_counter

    @property
    def active(self):
        """Gets the active of this SubscriptionUsage.  # noqa: E501


        :return: The active of this SubscriptionUsage.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this SubscriptionUsage.


        :param active: The active of this SubscriptionUsage.  # noqa: E501
        :type: bool
        """

        self._active = active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SubscriptionUsage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AddBarcodeAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'barcode_type': 'str',
        'value': 'str',
        'height': 'int',
        'width': 'int',
        'align_x': 'str',
        'align_y': 'str',
        'margin_x': 'int',
        'margin_y': 'int',
        'page_sequence': 'str',
        'rotate': 'int',
        'barcode_color': 'BarcodeColor',
        'background_color': 'BarcodeColor',
        'action_id': 'str'
    }

    attribute_map = {
        'barcode_type': 'barcodeType',
        'value': 'value',
        'height': 'height',
        'width': 'width',
        'align_x': 'alignX',
        'align_y': 'alignY',
        'margin_x': 'marginX',
        'margin_y': 'marginY',
        'page_sequence': 'pageSequence',
        'rotate': 'rotate',
        'barcode_color': 'barcodeColor',
        'background_color': 'backgroundColor',
        'action_id': 'actionId'
    }

    def __init__(self, barcode_type=None, value=None, height=None, width=None, align_x=None, align_y=None, margin_x=None, margin_y=None, page_sequence=None, rotate=None, barcode_color=None, background_color=None, action_id=None):  # noqa: E501
        """AddBarcodeAction - a model defined in Swagger"""  # noqa: E501

        self._barcode_type = None
        self._value = None
        self._height = None
        self._width = None
        self._align_x = None
        self._align_y = None
        self._margin_x = None
        self._margin_y = None
        self._page_sequence = None
        self._rotate = None
        self._barcode_color = None
        self._background_color = None
        self._action_id = None
        self.discriminator = None

        if barcode_type is not None:
            self.barcode_type = barcode_type
        if value is not None:
            self.value = value
        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if align_x is not None:
            self.align_x = align_x
        if align_y is not None:
            self.align_y = align_y
        if margin_x is not None:
            self.margin_x = margin_x
        if margin_y is not None:
            self.margin_y = margin_y
        if page_sequence is not None:
            self.page_sequence = page_sequence
        if rotate is not None:
            self.rotate = rotate
        if barcode_color is not None:
            self.barcode_color = barcode_color
        if background_color is not None:
            self.background_color = background_color
        if action_id is not None:
            self.action_id = action_id

    @property
    def barcode_type(self):
        """Gets the barcode_type of this AddBarcodeAction.  # noqa: E501


        :return: The barcode_type of this AddBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._barcode_type

    @barcode_type.setter
    def barcode_type(self, barcode_type):
        """Sets the barcode_type of this AddBarcodeAction.


        :param barcode_type: The barcode_type of this AddBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "code11", "code2Of5Standard", "code2Of5Interleaved", "code2Of5Iata", "code2Of5Matrix", "code2Of5DataLogic", "code2Of5Industry", "code39", "code39Extended", "ean8", "ean8With2Addon", "ean8With5Addon", "ean13", "ean13With2Addon", "ean13With5Addon", "eanUcc128", "upc12", "codabar2", "codabar18", "code128", "deutschePostLeitcode", "deutschePostIdentcode", "isbn13With5Addon", "ismn", "code93", "issn", "issnWith2Addon", "flattermarken", "gs1DataBar", "gs1DataBarLimited", "gs1DataBarExpanded", "telepenAlpha", "ucc128", "upcA", "upcAWith2Addon", "upcAWith5Addon", "upcE", "upcEWith2Addon", "upcEWith5Addon", "uspsPostnet5", "uspsPostnet6", "uspsPostnet9", "uspsPostnet10", "uspsPostnet11", "uspsPostnet12", "plessey", "msi", "sscc18", "fim", "logmars", "pharmacodeOneTrack", "pzn7", "pharmacodeTwoTrack", "cepNet", "pdf417", "pdf417Truncated", "maxicode", "qrCode", "code128SubsetA", "code128SubsetB", "code128SubsetC", "code93Extended", "australianPostCustom", "australianPostCustom2", "australianPostCustom3", "australianPostReplyPaid", "australianPostRouting", "australianPostRedirection", "isbn13", "rm4Scc", "dataMatrix", "ean14", "vin", "codablockF", "nve18", "japanesePostal", "koreanPostalAuthority", "gs1DataBarTruncated", "gs1DataBarStacked", "gs1DataBarStackedOmnidirectional", "gs1DataBarExpandedStacked", "planet12", "planet14", "microPdf417", "uspsIntelligentMail", "plesseyBidirectional", "telepen", "gs1_128", "itf14", "kix", "code32", "aztec", "italianPostal2Of5", "italianPostal3Of9", "dpd", "microQRCode", "hibcLic128", "hibcLic3OF9", "hibcPas128", "hibcPas3OF9", "hibcLicDataMatrix", "hibcPasDataMatrix", "hibcLicQRCode", "hibcPasQRCode", "hibcLicPDF417", "hibcPasPDF417", "hibcLicMPDF417", "hibcPasMPDF417", "hibcLicCODABLOCK_F", "hibcPasCODABLOCK_F", "qrcode2005", "pzn8", "dotCode", "hanXin", "uSPSIMPackage", "swedishPostalShipmentId", "mailmark_2D", "upuS10", "mailmark_4state", "hibcLicAztec", "hibcPasAztec", "ppn", "ntin", "swissQrCode"]  # noqa: E501
        if barcode_type not in allowed_values:
            raise ValueError(
                "Invalid value for `barcode_type` ({0}), must be one of {1}"  # noqa: E501
                .format(barcode_type, allowed_values)
            )

        self._barcode_type = barcode_type

    @property
    def value(self):
        """Gets the value of this AddBarcodeAction.  # noqa: E501


        :return: The value of this AddBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this AddBarcodeAction.


        :param value: The value of this AddBarcodeAction.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def height(self):
        """Gets the height of this AddBarcodeAction.  # noqa: E501


        :return: The height of this AddBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this AddBarcodeAction.


        :param height: The height of this AddBarcodeAction.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def width(self):
        """Gets the width of this AddBarcodeAction.  # noqa: E501


        :return: The width of this AddBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this AddBarcodeAction.


        :param width: The width of this AddBarcodeAction.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def align_x(self):
        """Gets the align_x of this AddBarcodeAction.  # noqa: E501


        :return: The align_x of this AddBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._align_x

    @align_x.setter
    def align_x(self, align_x):
        """Sets the align_x of this AddBarcodeAction.


        :param align_x: The align_x of this AddBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["left", "center", "right"]  # noqa: E501
        if align_x not in allowed_values:
            raise ValueError(
                "Invalid value for `align_x` ({0}), must be one of {1}"  # noqa: E501
                .format(align_x, allowed_values)
            )

        self._align_x = align_x

    @property
    def align_y(self):
        """Gets the align_y of this AddBarcodeAction.  # noqa: E501


        :return: The align_y of this AddBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._align_y

    @align_y.setter
    def align_y(self, align_y):
        """Sets the align_y of this AddBarcodeAction.


        :param align_y: The align_y of this AddBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["top", "middle", "bottom"]  # noqa: E501
        if align_y not in allowed_values:
            raise ValueError(
                "Invalid value for `align_y` ({0}), must be one of {1}"  # noqa: E501
                .format(align_y, allowed_values)
            )

        self._align_y = align_y

    @property
    def margin_x(self):
        """Gets the margin_x of this AddBarcodeAction.  # noqa: E501


        :return: The margin_x of this AddBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._margin_x

    @margin_x.setter
    def margin_x(self, margin_x):
        """Sets the margin_x of this AddBarcodeAction.


        :param margin_x: The margin_x of this AddBarcodeAction.  # noqa: E501
        :type: int
        """

        self._margin_x = margin_x

    @property
    def margin_y(self):
        """Gets the margin_y of this AddBarcodeAction.  # noqa: E501


        :return: The margin_y of this AddBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._margin_y

    @margin_y.setter
    def margin_y(self, margin_y):
        """Sets the margin_y of this AddBarcodeAction.


        :param margin_y: The margin_y of this AddBarcodeAction.  # noqa: E501
        :type: int
        """

        self._margin_y = margin_y

    @property
    def page_sequence(self):
        """Gets the page_sequence of this AddBarcodeAction.  # noqa: E501


        :return: The page_sequence of this AddBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._page_sequence

    @page_sequence.setter
    def page_sequence(self, page_sequence):
        """Sets the page_sequence of this AddBarcodeAction.


        :param page_sequence: The page_sequence of this AddBarcodeAction.  # noqa: E501
        :type: str
        """

        self._page_sequence = page_sequence

    @property
    def rotate(self):
        """Gets the rotate of this AddBarcodeAction.  # noqa: E501


        :return: The rotate of this AddBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """Sets the rotate of this AddBarcodeAction.


        :param rotate: The rotate of this AddBarcodeAction.  # noqa: E501
        :type: int
        """

        self._rotate = rotate

    @property
    def barcode_color(self):
        """Gets the barcode_color of this AddBarcodeAction.  # noqa: E501


        :return: The barcode_color of this AddBarcodeAction.  # noqa: E501
        :rtype: BarcodeColor
        """
        return self._barcode_color

    @barcode_color.setter
    def barcode_color(self, barcode_color):
        """Sets the barcode_color of this AddBarcodeAction.


        :param barcode_color: The barcode_color of this AddBarcodeAction.  # noqa: E501
        :type: BarcodeColor
        """

        self._barcode_color = barcode_color

    @property
    def background_color(self):
        """Gets the background_color of this AddBarcodeAction.  # noqa: E501


        :return: The background_color of this AddBarcodeAction.  # noqa: E501
        :rtype: BarcodeColor
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """Sets the background_color of this AddBarcodeAction.


        :param background_color: The background_color of this AddBarcodeAction.  # noqa: E501
        :type: BarcodeColor
        """

        self._background_color = background_color

    @property
    def action_id(self):
        """Gets the action_id of this AddBarcodeAction.  # noqa: E501


        :return: The action_id of this AddBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this AddBarcodeAction.


        :param action_id: The action_id of this AddBarcodeAction.  # noqa: E501
        :type: str
        """

        self._action_id = action_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddBarcodeAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddBarcodeAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Machine(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active': 'bool',
        'enabled': 'bool',
        'machine_id_ext': 'str',
        'machine_name': 'str',
        'last_update': 'datetime'
    }

    attribute_map = {
        'active': 'active',
        'enabled': 'enabled',
        'machine_id_ext': 'machineIdExt',
        'machine_name': 'machineName',
        'last_update': 'lastUpdate'
    }

    def __init__(self, active=None, enabled=None, machine_id_ext=None, machine_name=None, last_update=None):  # noqa: E501
        """Machine - a model defined in Swagger"""  # noqa: E501

        self._active = None
        self._enabled = None
        self._machine_id_ext = None
        self._machine_name = None
        self._last_update = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if enabled is not None:
            self.enabled = enabled
        if machine_id_ext is not None:
            self.machine_id_ext = machine_id_ext
        if machine_name is not None:
            self.machine_name = machine_name
        if last_update is not None:
            self.last_update = last_update

    @property
    def active(self):
        """Gets the active of this Machine.  # noqa: E501


        :return: The active of this Machine.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Machine.


        :param active: The active of this Machine.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def enabled(self):
        """Gets the enabled of this Machine.  # noqa: E501


        :return: The enabled of this Machine.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this Machine.


        :param enabled: The enabled of this Machine.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def machine_id_ext(self):
        """Gets the machine_id_ext of this Machine.  # noqa: E501


        :return: The machine_id_ext of this Machine.  # noqa: E501
        :rtype: str
        """
        return self._machine_id_ext

    @machine_id_ext.setter
    def machine_id_ext(self, machine_id_ext):
        """Sets the machine_id_ext of this Machine.


        :param machine_id_ext: The machine_id_ext of this Machine.  # noqa: E501
        :type: str
        """

        self._machine_id_ext = machine_id_ext

    @property
    def machine_name(self):
        """Gets the machine_name of this Machine.  # noqa: E501


        :return: The machine_name of this Machine.  # noqa: E501
        :rtype: str
        """
        return self._machine_name

    @machine_name.setter
    def machine_name(self, machine_name):
        """Sets the machine_name of this Machine.


        :param machine_name: The machine_name of this Machine.  # noqa: E501
        :type: str
        """

        self._machine_name = machine_name

    @property
    def last_update(self):
        """Gets the last_update of this Machine.  # noqa: E501


        :return: The last_update of this Machine.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update

    @last_update.setter
    def last_update(self, last_update):
        """Sets the last_update of this Machine.


        :param last_update: The last_update of this Machine.  # noqa: E501
        :type: datetime
        """

        self._last_update = last_update

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Machine, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Machine):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pdf4me.model import JobFlow, JobFlowPlan, RunJobFlow, JobConfig, Machine


class JobClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    # def create_archive_job_config(self, archive_job_req):  
    #     """CreateArchiveJobConfig  
    #
    #     Create Archive Job which continuously converts your PDF to Pdf-A.  
    #
    #     :param ArchiveJobReq archive_job_req:
    #     :return: ArchiveJobRes
    #     """
    #     res = self.pdf4me_client.custom_http.post_universal_object(universal_object=archive_job_req,
    #                                                                controller='Job/CreateArchiveJobConfig')
    #
    #     return res

    def delete_job_flow(self, job_flow_req): 
        """delete_job_flow  

        :param JobFlow job_flow_req:
        :return: DeleteJobFlowRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=job_flow_req,
                                                                   controller='Job/DeleteJobFlow')

        return res

    def delete_job_flow_plan(self, job_flow_plan_req):  
        """delete_job_flow_plan  

        :param JobFlowPlan job_flow_plan_req:
        :return: DeleteJobFlowPlanRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=job_flow_plan_req,
                                                                   controller='Job/DeleteJobFlowPlan')

        return res

    def get_all_job_flow_plans(self):  
        """get_all_job_flow_plans  

        :return: GetJobFlowPlanRes
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Job/GetAllJobFlowPlans')

    def get_all_job_flows(self):  
        """get_all_job_flows  

        :return: GetJobFlowRes
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Job/GetAllJobFlows')

    def get_job_flows(self, job_flow_id):  
        """get_job_flows  

        :param str job_flow_id:
        :return: list[JobFlow]
        """
        params = [('jobFlowId', job_flow_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Job/GetJobFlows')

    def get_job_flows_by_machine_id(self, machine_id):  
        """get_job_flows_by_machine_id  

        :param str machine_id:
        :return: list[JobFlow]
        """
        params = [('machineId', machine_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Job/GetJobFlows')

    def get_machines(self):  
        """get_machines  

        :return: GetMachineRes
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Job/GetMachines')

    def job_configs(self):  
        """JobConfigs  

        :return: list[JobConfig]
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Job/JobConfigs')

    def run_job_flow(self, run_job_flow):  
        """run_job_flow  

        :param RunJobFlow run_job_flow:
        :return: RunJobRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=run_job_flow,
                                                                   controller='Job/RunJobFlow')

        return res

    def save_job_config(self, job_config):  
        """SaveJobConfig  

        Create a Job Configuration for recurring executions or pipelining of pdf4me functionality.  With pipelining it is possible to run pdf4me base functionality in a specific order as a single execution.  

        :param JobConfig job_config:
        :return: JobConfigRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=job_config,
                                                                   controller='Job/SaveJobConfig')

        return res

    def save_job_flow(self, job_flow_req):  
        """save_job_flow  

        :param JobFlow job_flow_req:
        :return: SaveJobFlowRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=job_flow_req,
                                                                   controller='Job/SaveJobFlow')

        return res

    def save_job_flow_plan(self, job_flow_plan_req):  
        """save_job_flow_plan  

        :param JobFlowPlan job_flow_plan_req:
        :return: SaveJobFlowPlanRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=job_flow_plan_req,
                                                                   controller='Job/SaveJobFlowPlan')

        return res

    def save_job_flows(self, job_flow):  
        """save_job_flows  

        :param JobFlow job_flow:
        :return: JobFlowPlan
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=job_flow,
                                                                   controller='Job/SaveJobFlows')

        return res

    def save_machine(self, machine_req):  
        """save_machine  

        :param Machine machine_req:
        :return: SaveMachineRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=machine_req,
                                                                   controller='Job/SaveMachine')

        return res



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CustomerBO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer_id': 'str',
        'tenant_id': 'str',
        'subscription_id': 'str',
        'active': 'bool',
        'pdf4me_type': 'str',
        'vat': 'str',
        'country_code': 'str',
        'currency': 'str',
        'language': 'str',
        'company_name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'street': 'str',
        'zip': 'str',
        'city': 'str',
        'ip_adr': 'str',
        'creation_date': 'datetime',
        'creation_name': 'str',
        'mod_date': 'datetime',
        'mod_name': 'str',
        'email': 'str',
        'charge_bee_customer_id': 'str',
        'validation_res': 'list[KeyValuePairStringString]'
    }

    attribute_map = {
        'customer_id': 'customerId',
        'tenant_id': 'tenantId',
        'subscription_id': 'subscriptionId',
        'active': 'active',
        'pdf4me_type': 'pdf4meType',
        'vat': 'vat',
        'country_code': 'countryCode',
        'currency': 'currency',
        'language': 'language',
        'company_name': 'companyName',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'street': 'street',
        'zip': 'zip',
        'city': 'city',
        'ip_adr': 'ipAdr',
        'creation_date': 'creationDate',
        'creation_name': 'creationName',
        'mod_date': 'modDate',
        'mod_name': 'modName',
        'email': 'email',
        'charge_bee_customer_id': 'chargeBeeCustomerId',
        'validation_res': 'validationRes'
    }

    def __init__(self, customer_id=None, tenant_id=None, subscription_id=None, active=None, pdf4me_type=None, vat=None, country_code=None, currency=None, language=None, company_name=None, first_name=None, last_name=None, street=None, zip=None, city=None, ip_adr=None, creation_date=None, creation_name=None, mod_date=None, mod_name=None, email=None, charge_bee_customer_id=None, validation_res=None):  # noqa: E501
        """CustomerBO - a model defined in Swagger"""  # noqa: E501

        self._customer_id = None
        self._tenant_id = None
        self._subscription_id = None
        self._active = None
        self._pdf4me_type = None
        self._vat = None
        self._country_code = None
        self._currency = None
        self._language = None
        self._company_name = None
        self._first_name = None
        self._last_name = None
        self._street = None
        self._zip = None
        self._city = None
        self._ip_adr = None
        self._creation_date = None
        self._creation_name = None
        self._mod_date = None
        self._mod_name = None
        self._email = None
        self._charge_bee_customer_id = None
        self._validation_res = None
        self.discriminator = None

        if customer_id is not None:
            self.customer_id = customer_id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if active is not None:
            self.active = active
        if pdf4me_type is not None:
            self.pdf4me_type = pdf4me_type
        if vat is not None:
            self.vat = vat
        if country_code is not None:
            self.country_code = country_code
        if currency is not None:
            self.currency = currency
        if language is not None:
            self.language = language
        if company_name is not None:
            self.company_name = company_name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if street is not None:
            self.street = street
        if zip is not None:
            self.zip = zip
        if city is not None:
            self.city = city
        if ip_adr is not None:
            self.ip_adr = ip_adr
        if creation_date is not None:
            self.creation_date = creation_date
        if creation_name is not None:
            self.creation_name = creation_name
        if mod_date is not None:
            self.mod_date = mod_date
        if mod_name is not None:
            self.mod_name = mod_name
        if email is not None:
            self.email = email
        if charge_bee_customer_id is not None:
            self.charge_bee_customer_id = charge_bee_customer_id
        if validation_res is not None:
            self.validation_res = validation_res

    @property
    def customer_id(self):
        """Gets the customer_id of this CustomerBO.  # noqa: E501


        :return: The customer_id of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this CustomerBO.


        :param customer_id: The customer_id of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._customer_id = customer_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this CustomerBO.  # noqa: E501


        :return: The tenant_id of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this CustomerBO.


        :param tenant_id: The tenant_id of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this CustomerBO.  # noqa: E501


        :return: The subscription_id of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this CustomerBO.


        :param subscription_id: The subscription_id of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def active(self):
        """Gets the active of this CustomerBO.  # noqa: E501


        :return: The active of this CustomerBO.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this CustomerBO.


        :param active: The active of this CustomerBO.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def pdf4me_type(self):
        """Gets the pdf4me_type of this CustomerBO.  # noqa: E501


        :return: The pdf4me_type of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._pdf4me_type

    @pdf4me_type.setter
    def pdf4me_type(self, pdf4me_type):
        """Sets the pdf4me_type of this CustomerBO.


        :param pdf4me_type: The pdf4me_type of this CustomerBO.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "api", "consumer"]  # noqa: E501
        if pdf4me_type not in allowed_values:
            raise ValueError(
                "Invalid value for `pdf4me_type` ({0}), must be one of {1}"  # noqa: E501
                .format(pdf4me_type, allowed_values)
            )

        self._pdf4me_type = pdf4me_type

    @property
    def vat(self):
        """Gets the vat of this CustomerBO.  # noqa: E501


        :return: The vat of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._vat

    @vat.setter
    def vat(self, vat):
        """Sets the vat of this CustomerBO.


        :param vat: The vat of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._vat = vat

    @property
    def country_code(self):
        """Gets the country_code of this CustomerBO.  # noqa: E501


        :return: The country_code of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this CustomerBO.


        :param country_code: The country_code of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def currency(self):
        """Gets the currency of this CustomerBO.  # noqa: E501


        :return: The currency of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this CustomerBO.


        :param currency: The currency of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def language(self):
        """Gets the language of this CustomerBO.  # noqa: E501


        :return: The language of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this CustomerBO.


        :param language: The language of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def company_name(self):
        """Gets the company_name of this CustomerBO.  # noqa: E501


        :return: The company_name of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this CustomerBO.


        :param company_name: The company_name of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def first_name(self):
        """Gets the first_name of this CustomerBO.  # noqa: E501


        :return: The first_name of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this CustomerBO.


        :param first_name: The first_name of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this CustomerBO.  # noqa: E501


        :return: The last_name of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this CustomerBO.


        :param last_name: The last_name of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def street(self):
        """Gets the street of this CustomerBO.  # noqa: E501


        :return: The street of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this CustomerBO.


        :param street: The street of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._street = street

    @property
    def zip(self):
        """Gets the zip of this CustomerBO.  # noqa: E501


        :return: The zip of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this CustomerBO.


        :param zip: The zip of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._zip = zip

    @property
    def city(self):
        """Gets the city of this CustomerBO.  # noqa: E501


        :return: The city of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this CustomerBO.


        :param city: The city of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def ip_adr(self):
        """Gets the ip_adr of this CustomerBO.  # noqa: E501


        :return: The ip_adr of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._ip_adr

    @ip_adr.setter
    def ip_adr(self, ip_adr):
        """Sets the ip_adr of this CustomerBO.


        :param ip_adr: The ip_adr of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._ip_adr = ip_adr

    @property
    def creation_date(self):
        """Gets the creation_date of this CustomerBO.  # noqa: E501


        :return: The creation_date of this CustomerBO.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this CustomerBO.


        :param creation_date: The creation_date of this CustomerBO.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def creation_name(self):
        """Gets the creation_name of this CustomerBO.  # noqa: E501


        :return: The creation_name of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._creation_name

    @creation_name.setter
    def creation_name(self, creation_name):
        """Sets the creation_name of this CustomerBO.


        :param creation_name: The creation_name of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._creation_name = creation_name

    @property
    def mod_date(self):
        """Gets the mod_date of this CustomerBO.  # noqa: E501


        :return: The mod_date of this CustomerBO.  # noqa: E501
        :rtype: datetime
        """
        return self._mod_date

    @mod_date.setter
    def mod_date(self, mod_date):
        """Sets the mod_date of this CustomerBO.


        :param mod_date: The mod_date of this CustomerBO.  # noqa: E501
        :type: datetime
        """

        self._mod_date = mod_date

    @property
    def mod_name(self):
        """Gets the mod_name of this CustomerBO.  # noqa: E501


        :return: The mod_name of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._mod_name

    @mod_name.setter
    def mod_name(self, mod_name):
        """Sets the mod_name of this CustomerBO.


        :param mod_name: The mod_name of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._mod_name = mod_name

    @property
    def email(self):
        """Gets the email of this CustomerBO.  # noqa: E501


        :return: The email of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CustomerBO.


        :param email: The email of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def charge_bee_customer_id(self):
        """Gets the charge_bee_customer_id of this CustomerBO.  # noqa: E501


        :return: The charge_bee_customer_id of this CustomerBO.  # noqa: E501
        :rtype: str
        """
        return self._charge_bee_customer_id

    @charge_bee_customer_id.setter
    def charge_bee_customer_id(self, charge_bee_customer_id):
        """Sets the charge_bee_customer_id of this CustomerBO.


        :param charge_bee_customer_id: The charge_bee_customer_id of this CustomerBO.  # noqa: E501
        :type: str
        """

        self._charge_bee_customer_id = charge_bee_customer_id

    @property
    def validation_res(self):
        """Gets the validation_res of this CustomerBO.  # noqa: E501


        :return: The validation_res of this CustomerBO.  # noqa: E501
        :rtype: list[KeyValuePairStringString]
        """
        return self._validation_res

    @validation_res.setter
    def validation_res(self, validation_res):
        """Sets the validation_res of this CustomerBO.


        :param validation_res: The validation_res of this CustomerBO.  # noqa: E501
        :type: list[KeyValuePairStringString]
        """

        self._validation_res = validation_res

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomerBO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomerBO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Package(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'package_id': 'str',
        'name': 'str',
        'creation_date': 'datetime',
        'creation_name': 'str',
        'mod_date': 'datetime',
        'mod_name': 'str',
        'version': 'str',
        'download_url': 'str'
    }

    attribute_map = {
        'package_id': 'packageId',
        'name': 'name',
        'creation_date': 'creationDate',
        'creation_name': 'creationName',
        'mod_date': 'modDate',
        'mod_name': 'modName',
        'version': 'version',
        'download_url': 'downloadUrl'
    }

    def __init__(self, package_id=None, name=None, creation_date=None, creation_name=None, mod_date=None, mod_name=None, version=None, download_url=None):  # noqa: E501
        """Package - a model defined in Swagger"""  # noqa: E501

        self._package_id = None
        self._name = None
        self._creation_date = None
        self._creation_name = None
        self._mod_date = None
        self._mod_name = None
        self._version = None
        self._download_url = None
        self.discriminator = None

        if package_id is not None:
            self.package_id = package_id
        if name is not None:
            self.name = name
        if creation_date is not None:
            self.creation_date = creation_date
        if creation_name is not None:
            self.creation_name = creation_name
        if mod_date is not None:
            self.mod_date = mod_date
        if mod_name is not None:
            self.mod_name = mod_name
        if version is not None:
            self.version = version
        if download_url is not None:
            self.download_url = download_url

    @property
    def package_id(self):
        """Gets the package_id of this Package.  # noqa: E501


        :return: The package_id of this Package.  # noqa: E501
        :rtype: str
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """Sets the package_id of this Package.


        :param package_id: The package_id of this Package.  # noqa: E501
        :type: str
        """

        self._package_id = package_id

    @property
    def name(self):
        """Gets the name of this Package.  # noqa: E501


        :return: The name of this Package.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Package.


        :param name: The name of this Package.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def creation_date(self):
        """Gets the creation_date of this Package.  # noqa: E501


        :return: The creation_date of this Package.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this Package.


        :param creation_date: The creation_date of this Package.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def creation_name(self):
        """Gets the creation_name of this Package.  # noqa: E501


        :return: The creation_name of this Package.  # noqa: E501
        :rtype: str
        """
        return self._creation_name

    @creation_name.setter
    def creation_name(self, creation_name):
        """Sets the creation_name of this Package.


        :param creation_name: The creation_name of this Package.  # noqa: E501
        :type: str
        """

        self._creation_name = creation_name

    @property
    def mod_date(self):
        """Gets the mod_date of this Package.  # noqa: E501


        :return: The mod_date of this Package.  # noqa: E501
        :rtype: datetime
        """
        return self._mod_date

    @mod_date.setter
    def mod_date(self, mod_date):
        """Sets the mod_date of this Package.


        :param mod_date: The mod_date of this Package.  # noqa: E501
        :type: datetime
        """

        self._mod_date = mod_date

    @property
    def mod_name(self):
        """Gets the mod_name of this Package.  # noqa: E501


        :return: The mod_name of this Package.  # noqa: E501
        :rtype: str
        """
        return self._mod_name

    @mod_name.setter
    def mod_name(self, mod_name):
        """Sets the mod_name of this Package.


        :param mod_name: The mod_name of this Package.  # noqa: E501
        :type: str
        """

        self._mod_name = mod_name

    @property
    def version(self):
        """Gets the version of this Package.  # noqa: E501


        :return: The version of this Package.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Package.


        :param version: The version of this Package.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def download_url(self):
        """Gets the download_url of this Package.  # noqa: E501


        :return: The download_url of this Package.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this Package.


        :param download_url: The download_url of this Package.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Package, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Package):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SplitByBarcodeAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'barcode_string': 'str',
        'barcode_filter': 'str',
        'barcode_type': 'str',
        'split_barcode_page': 'str',
        'action_id': 'str'
    }

    attribute_map = {
        'barcode_string': 'barcodeString',
        'barcode_filter': 'barcodeFilter',
        'barcode_type': 'barcodeType',
        'split_barcode_page': 'splitBarcodePage',
        'action_id': 'actionId'
    }

    def __init__(self, barcode_string=None, barcode_filter=None, barcode_type=None, split_barcode_page=None, action_id=None):  # noqa: E501
        """SplitByBarcodeAction - a model defined in Swagger"""  # noqa: E501

        self._barcode_string = None
        self._barcode_filter = None
        self._barcode_type = None
        self._split_barcode_page = None
        self._action_id = None
        self.discriminator = None

        if barcode_string is not None:
            self.barcode_string = barcode_string
        if barcode_filter is not None:
            self.barcode_filter = barcode_filter
        if barcode_type is not None:
            self.barcode_type = barcode_type
        if split_barcode_page is not None:
            self.split_barcode_page = split_barcode_page
        if action_id is not None:
            self.action_id = action_id

    @property
    def barcode_string(self):
        """Gets the barcode_string of this SplitByBarcodeAction.  # noqa: E501


        :return: The barcode_string of this SplitByBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._barcode_string

    @barcode_string.setter
    def barcode_string(self, barcode_string):
        """Sets the barcode_string of this SplitByBarcodeAction.


        :param barcode_string: The barcode_string of this SplitByBarcodeAction.  # noqa: E501
        :type: str
        """

        self._barcode_string = barcode_string

    @property
    def barcode_filter(self):
        """Gets the barcode_filter of this SplitByBarcodeAction.  # noqa: E501


        :return: The barcode_filter of this SplitByBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._barcode_filter

    @barcode_filter.setter
    def barcode_filter(self, barcode_filter):
        """Sets the barcode_filter of this SplitByBarcodeAction.


        :param barcode_filter: The barcode_filter of this SplitByBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["startsWith", "endsWith", "contains", "exact"]  # noqa: E501
        if barcode_filter not in allowed_values:
            raise ValueError(
                "Invalid value for `barcode_filter` ({0}), must be one of {1}"  # noqa: E501
                .format(barcode_filter, allowed_values)
            )

        self._barcode_filter = barcode_filter

    @property
    def barcode_type(self):
        """Gets the barcode_type of this SplitByBarcodeAction.  # noqa: E501


        :return: The barcode_type of this SplitByBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._barcode_type

    @barcode_type.setter
    def barcode_type(self, barcode_type):
        """Sets the barcode_type of this SplitByBarcodeAction.


        :param barcode_type: The barcode_type of this SplitByBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["any", "datamatrix", "qrcode"]  # noqa: E501
        if barcode_type not in allowed_values:
            raise ValueError(
                "Invalid value for `barcode_type` ({0}), must be one of {1}"  # noqa: E501
                .format(barcode_type, allowed_values)
            )

        self._barcode_type = barcode_type

    @property
    def split_barcode_page(self):
        """Gets the split_barcode_page of this SplitByBarcodeAction.  # noqa: E501


        :return: The split_barcode_page of this SplitByBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._split_barcode_page

    @split_barcode_page.setter
    def split_barcode_page(self, split_barcode_page):
        """Sets the split_barcode_page of this SplitByBarcodeAction.


        :param split_barcode_page: The split_barcode_page of this SplitByBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["before", "after", "remove"]  # noqa: E501
        if split_barcode_page not in allowed_values:
            raise ValueError(
                "Invalid value for `split_barcode_page` ({0}), must be one of {1}"  # noqa: E501
                .format(split_barcode_page, allowed_values)
            )

        self._split_barcode_page = split_barcode_page

    @property
    def action_id(self):
        """Gets the action_id of this SplitByBarcodeAction.  # noqa: E501


        :return: The action_id of this SplitByBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this SplitByBarcodeAction.


        :param action_id: The action_id of this SplitByBarcodeAction.  # noqa: E501
        :type: str
        """

        self._action_id = action_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SplitByBarcodeAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SplitByBarcodeAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pdf4me.model import CreateMailing, MailMergeDoc, MailMergeJob


class DocGenerationClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def create_mailing(self, create_mailing):
        """create_mailing

        :param create_mailing:
        :type create_mailing: CreateMailing
        :return: CreateMailingRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=create_mailing,
                                                                   controller='DocGeneration/CreateMailing')

        return res

    def mail_merge(self, file, jobid_ext):
        """The provided Non-PDF file gets converted to a PDF.

        :param jobid_ext:
        :type jobid_ext:
        :param file: file to be converted
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting PDF file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('jobIdExt', jobid_ext)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='DocGeneration/MailMerge')

    def mail_merge_doc(self, mail_merge_doc):
        """mail_merge_doc

        :param mail_merge_doc:
        :type mail_merge_doc: MailMergeDoc
        :return: MailMergeDocRes
        """

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=mail_merge_doc,
                                                                   controller='DocGeneration/MailMergeDoc')

        return res

    def mail_merge_job(self, mail_merge_job):
        """mail_merge_job

        :param mail_merge_job:
        :type mail_merge_job: MailMergeJob
        :return: MailMergeJobRes
        """

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=mail_merge_job,
                                                                   controller='DocGeneration/MailMergeJob')

        return res



from pdf4me.model import DropDocumentReq, ProduceDocuments


class DocumentApi(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def drop_document(self, drop_document_req):
        """drop_document

        :param drop_document_req:
        :type drop_document_req: DropDocumentReq
        :return: DropDocumentRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=drop_document_req,
                                                                   controller='Document/DropDocument')

        return res

    def get_document(self, job_id, document_id):
        """get_document

        :param job_id:
        :type job_id:str
        :param document_id:
        :type document_id:str
        :return: file
        """
        params = [('jobId', job_id), ('documentId', document_id)]

        return self.pdf4me_client.custom_http.get_wrapper(query_strings=params, controller='Document/GetDocument')

    def get_documents(self, job_id):
        """get_document_url

        :param job_id:
        :type job_id:str
        :return: GetDocumentListRes
        """
        params = [('jobId', job_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Document/GetDocuments')

    def get_document_url(self,  job_id, document_id):
        """get_document_url

        :param job_id:
        :type job_id:str
        :param document_id:
        :type document_id:str
        :return: GetDocumentUrlRes
        """
        params = [('jobId', job_id), ('documentId', document_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Document/GetDocumentUrl')

    def get_document_url_with_ext(self, job_id, document_id, file_name):
        """get_document_url_with_ext

        :param str job_id:
        :param str document_id:
        :param str file_name:
        :return: GetDocumentUrlRes
        """
        params = [('jobId', job_id), ('documentId', document_id), ('fileName', file_name)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params,
                                                         controller='Document/GetDocumentUrlWithExt')

    def get_image_url(self,  job_id, image_id):
        """get_document_url

        :param job_id:
        :type job_id:str
        :param image_id:
        :type image_id:str
        :return: GetDocumentUrlRes
        """
        params = [('jobId', job_id), ('imageId', image_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='Document/GetImageUrl')

    def get_image_url_with_ext(self, job_id, image_id, file_name):
        """get_document_url_with_ext

        :param str job_id:
        :param str image_id:
        :param str file_name:
        :return: GetDocumentUrlRes
        """
        params = [('jobId', job_id), ('imageId', image_id), ('fileName', file_name)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params,
                                                         controller='Document/GetImageUrlWithExt')

    def produce_documents(self, produce_documents):
        """produce_documents

        :param ProduceDocuments produce_documents:
        :return: ProduceDocumentsRes
        """
        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=produce_documents,
                                                                   controller='Document/ProduceDocuments')

        return res



from pdf4me.model import UserPreference


class UserClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def get_customer(self):  
        """get_customer  

        :return: CustomerBO
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='User/GetCustomer')

    def get_user_applications(self):  
        """get_user_applications  

        :return: GetUserApplicationRes
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='User/GetUserApplications')

    def get_user_applications_by_login_id(self, login_id):  
        """get_user_applications_by_login_id  

        :param str login_id:
        :return: GetUserApplicationRes
        """
        params = [('loginId', login_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params,
                                                         controller='User/GetUserApplicationsByLoginId')

    def get_user_preference(self):  
        """get_user_preference  

        :return: GetUserPrefRes
        """
        params = []

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='User/GetUserPreference')

    def get_user_token(self, login_id):  
        """get_user_token  

        :param str login_id:
        :return: GetUserTokenRes
        """
        params = [('loginId', login_id)]

        return self.pdf4me_client.custom_http.get_object(query_strings=params, controller='User/GetUserToken')

    def save_user_preference(self, user_preference_req):  
        """save_user_preference  

        :param UserPreference user_preference_req:
        :return: SaveUserPrefRes
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object=user_preference_req,
                                                                    controller='User/SaveUserPreference')



from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import ReadBarcodes
from pdf4me.helper.json_converter import JsonConverter


class BarcodeClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def read_barcodes(self, read_barcodes):
        """The predefined read barcodes setting is carried out.

        :param read_barcodes: read barcode configuration
        :type read_barcodes: ReadBarcodes
        :return: ReadBarcodeRes, contains the barcode
        """

        # check read_barcodes validity
        self.__check_read_barcodes_object_validity(read_barcodes)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=read_barcodes,
                                                                   controller='Barcode/ReadBarcodes')

        return res

    def read_barcodes_by_type(self, barcode_type, file):
        """Reads barcodes from the file based on the barcode type

        :param barcode_type: barcode type
        :type barcode_type: str: ( 'all','unknown','code11','code39','code93','code128','codabar','inter2of5',
                                'patchcode','ean8','upce','ean13','upca','plus2','plus5','pdf417','datamatrix','qrcode',
                                'postnet','planet','rm4scc','australiapost','intelligentmail','code39extended',
                                'microqrcode','all_2d','pharmacode','ucc128','rss14','rsslimited','rssexpanded','all_1d')
        :param file: to be read barcode form
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: ReadBarcodeRes, contains the barcode
        """

        streams = [('file', file)]
        params = [('barcodeType', barcode_type)]

        res = self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                          controller='Barcode/ReadBarcodesByType')

        json_response = JsonConverter().load(res)

        return json_response

    def create_barcode_by_type(self, barcode_type, content):
        """Creates barcodes from the content based on the barcode type

        :param barcode_type: barcode type
        :type barcode_type: str: ( 'none','australianpostcustom','australianpostcustom2','australianpostcustom3',
                                'australianpostredirection','australianpostreplypaid','australianpostrouting','aztec',
                                'cepnet','codabar18','codabar2','codablockf','code11','code128','code128subseta',
                                'code128subsetb','code128subsetc','code2of5datalogic','code2of5iata','code2of5industry',
                                'code2of5interleaved','code2of5matrix','code2of5standard','code32','code39',
                                'code39extended','code93','code93extended','datamatrix','deutschepostidentcode',
                                'deutschepostleitcode','dotcode','dpd','ean13','ean13with2addon','ean13with5addon',
                                'ean14','ean8','ean8with2addon','ean8with5addon','eanucc128','fim','flattermarken',
                                'gs1_128','gs1databar','gs1databarexpanded','gs1databarexpandedstacked',
                                'gs1databarlimited','gs1databarstacked','gs1databarstackedomnidirectional',
                                'gs1databartruncated','hanxin','hibclic128','hibclic3of9','hibclicaztec',
                                'hibcliccodablock_f','hibclicdatamatrix','hibclicmpdf417','hibclicpdf417',
                                'hibclicqrcode','hibcpas128','hibcpas3of9','hibcpasaztec','hibcpascodablock_f',
                                'hibcpasdatamatrix','hibcpasmpdf417','hibcpaspdf417','hibcpasqrcode','isbn13',
                                'isbn13with5addon','ismn','issn','issnwith2addon','italianpostal2of5',
                                'italianpostal3of9','itf14','japanesepostal','kix','koreanpostalauthority','logmars',
                                'mailmark_2d','mailmark_4state','maxicode','micropdf417','microqrcode','msi','ntin',
                                'nve18','pdf417','pdf417truncated','pharmacodeonetrack','pharmacodetwotrack','planet12',
                                'planet14','plessey','plesseybidirectional','ppn','pzn7','pzn8','qrcode','qrcode2005',
                                'rm4scc','sscc18','swedishpostalshipmentid','swissqrcode','telepen','telepenalpha',
                                'ucc128','upc12','upca','upcawith2addon','upcawith5addon','upce','upcewith2addon',
                                'upcewith5addon','upus10','uspsimpackage','uspsintelligentmail','uspspostnet10',
                                'uspspostnet11','uspspostnet12','uspspostnet5','uspspostnet6','uspspostnet9','vin')
        :param content: text to be converted to barcode
        :type content: str
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = None
        params = [('barcodType', barcode_type), ('content', content)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Barcode/CreateBarcodeByType')

    def add_barcode(self, add_barcode):
        """Adds barcodes to the file based on the barcode type

        :param add_barcode: add barcode configuration
        :type add_barcode: AddBarcode
        :return: AddBarcodeRes, contains the barcoded document
        """

        # check add_barcode validity
        self.__check_add_barcode_object_validity(add_barcode)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=add_barcode,
                                                                   controller='Barcode/AddBarcode')

        return res

    def add_barcode_by_type(self, barcode_type, text, pages, align_x, align_y, height, width, file):  # noqa: E501
        """Adds barcodes to the file based on the barcode type

        :param barcode_type: barcode type
        :type barcode_type: str: ( 'none','australianpostcustom','australianpostcustom2','australianpostcustom3',
                                'australianpostredirection','australianpostreplypaid','australianpostrouting','aztec',
                                'cepnet','codabar18','codabar2','codablockf','code11','code128','code128subseta',
                                'code128subsetb','code128subsetc','code2of5datalogic','code2of5iata','code2of5industry',
                                'code2of5interleaved','code2of5matrix','code2of5standard','code32','code39',
                                'code39extended','code93','code93extended','datamatrix','deutschepostidentcode',
                                'deutschepostleitcode','dotcode','dpd','ean13','ean13with2addon','ean13with5addon',
                                'ean14','ean8','ean8with2addon','ean8with5addon','eanucc128','fim','flattermarken',
                                'gs1_128','gs1databar','gs1databarexpanded','gs1databarexpandedstacked',
                                'gs1databarlimited','gs1databarstacked','gs1databarstackedomnidirectional',
                                'gs1databartruncated','hanxin','hibclic128','hibclic3of9','hibclicaztec',
                                'hibcliccodablock_f','hibclicdatamatrix','hibclicmpdf417','hibclicpdf417',
                                'hibclicqrcode','hibcpas128','hibcpas3of9','hibcpasaztec','hibcpascodablock_f',
                                'hibcpasdatamatrix','hibcpasmpdf417','hibcpaspdf417','hibcpasqrcode','isbn13',
                                'isbn13with5addon','ismn','issn','issnwith2addon','italianpostal2of5',
                                'italianpostal3of9','itf14','japanesepostal','kix','koreanpostalauthority','logmars',
                                'mailmark_2d','mailmark_4state','maxicode','micropdf417','microqrcode','msi','ntin',
                                'nve18','pdf417','pdf417truncated','pharmacodeonetrack','pharmacodetwotrack','planet12',
                                'planet14','plessey','plesseybidirectional','ppn','pzn7','pzn8','qrcode','qrcode2005',
                                'rm4scc','sscc18','swedishpostalshipmentid','swissqrcode','telepen','telepenalpha',
                                'ucc128','upc12','upca','upcawith2addon','upcawith5addon','upce','upcewith2addon',
                                'upcewith5addon','upus10','uspsimpackage','uspsintelligentmail','uspspostnet10',
                                'uspspostnet11','uspspostnet12','uspspostnet5','uspspostnet6','uspspostnet9','vin')
        :param text: text to be converted to barcode
        :type text: str
        :param pages: pages to be stamped
        :type pages: str: {'all', 'first', 'last', 'odd', 'even', 'notFirst', 'otLast'} or a list of comma separated page numbers e.g. '1,4', if the first and fourth page need to be stamped
        :param align_x: horizontal position
        :type align_x: str: {'left', 'center', 'right'}
        :param align_y: vertical position
        :type align_y: str: {'top', 'middle', 'bottom'}
        :param height:
        :type height: int: height of barcode
        :param width:
        :type width: int: width of barcode
        :param file: to be barcoded
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk

        """
        streams = [('file', file)]
        params = [('barcodeType', barcode_type), ('text', text),
                  ('alignX', align_x), ('alignY', align_y),
                  ('pages', pages), ('height', height),
                  ('width', width)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Barcode/AddBarcodeByType')

    def split_by_barcode(self, split_by_barcode_req):
        """Splits the file based on the barcode type

        :param split_by_barcode_req: add barcode configuration
        :type split_by_barcode_req: SplitByBarcodeReq
        :return: SplitByBarcodeRes, contains the split documents
        """

        # check read_barcodes validity
        self.__check_split_by_barcode_req_object_validity(split_by_barcode_req)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=split_by_barcode_req,
                                                                   controller='Barcode/SplitByBarcode')

        return res

    def __check_read_barcodes_object_validity(self, read_barcodes):
        """checks whether the read_barcodes object contains the essential information to be
        processed by the server."""

        if read_barcodes is None:
            raise Pdf4meClientException('The read_barcodes parameter cannot be None.')
        elif read_barcodes.document is None or read_barcodes.document.doc_data is None:
            raise Pdf4meClientException('The read_barcodes document cannot be None.')
        elif read_barcodes.read_barcode_action is None:
            raise Pdf4meClientException('The read_barcode_action cannot be None.')

    def __check_add_barcode_object_validity(self, add_barcode):
        """checks whether the add_barcode object contains the essential information to be
        processed by the server."""

        if add_barcode is None:
            raise Pdf4meClientException('The add_barcode parameter cannot be None.')
        elif add_barcode.document is None or add_barcode.document.doc_data is None:
            raise Pdf4meClientException('The add_barcode document cannot be None.')
        elif add_barcode.add_barcode_action is None:
            raise Pdf4meClientException('The add_barcode_action cannot be None.')

    def __check_split_by_barcode_req_object_validity(self, split_by_barcode_req):
        """checks whether the split_by_barcode_req object contains the essential information to be
        processed by the server."""

        if split_by_barcode_req is None:
            raise Pdf4meClientException('The split_by_barcode_req parameter cannot be None.')
        elif split_by_barcode_req.document is None or split_by_barcode_req.document.doc_data is None:
            raise Pdf4meClientException('The split_by_barcode_req document cannot be None.')
        elif split_by_barcode_req.split_by_barcode_action is None:
            raise Pdf4meClientException('The split_by_barcode_action cannot be None.')
